@@ -3,7 +3,8 @@
 #' @description
 #' Function to calculate frost point (°C) from temperature (°C) and relative humidity (\%).
 #'
-#' This function is under development.
+#' @note
+#' This function is unstable and is under development.
 #'
 #' @details
 #' Formula coefficients from Arden Buck equation (1981, 1996) saturation vapor pressure over ice.
@@ -24,6 +25,8 @@
 #' @export
 #'
 #' @examples
+#' # calcFP is unstable and is under development
+#' # Frost point at 20°C (Temp) and 50% relative humidity (RH)
 #' calcFP(20, 50)
 #' calcFP(0, 50)
 #'
@@ -37,18 +40,20 @@
 #'
 calcFP <- function(Temp, RH) {
 
-  ## Arden Buck equation (1981, 1996) saturation vapor pressure over ice
-  a_ice = 6.1115
-  b_ice = 23.036
-  c_ice = 279.82
-  d_ice = 333.7
+  # Arden Buck (1981, 1996) coefficients for ice
+  a_ice <- 6.1115
+  b_ice <- 23.036
+  c_ice <- 279.82
+  d_ice <- 333.7
 
-  Pws_ice = a_ice * exp((b_ice - (Temp / d_ice)) * (Temp / (c_ice + Temp)))
-  Pw = Pws_ice * RH / 100
+  # Partial vapour pressure
+  Pws_ice <- a_ice * exp((b_ice - Temp / d_ice) * (Temp / (c_ice + Temp))) # Buck
+  Pw_ice <- Pws_ice * RH / 100
+
+  # Frost point (Tf)
+  # Tf = (c_ice * log(Pw / a_ice)) / (b_ice - log(Pw / a_ice))
+  Tf <- (c_ice * log(Pw_ice / a_ice)) / (b_ice - log(Pw_ice / a_ice))
 
-  ## Enhancement factor γ(T, RH)
-  Ef = log((RH / 100) * exp((b_ice - (Temp / d_ice)) * (Temp / (c_ice + Temp))))
-  Tf = (c_ice * Ef) / (b_ice - Ef)
   return(Tf)
 
 }
