@@ -1,7 +1,10 @@
 # inst/shiny/ConSciR-Tidy/app.R
 library(shiny)
 library(readxl)
+library(readr)
 library(tools)
+library(ggplot2)
+library(DT)
 
 options(shiny.maxRequestSize = 100 * 1024^2)
 
@@ -20,20 +23,18 @@ server <- function(input, output, session) {
     }
   })
 
-  # Download handler for tidied data
-  output$downloadData <- downloadHandler(
-    filename = function() {
-      paste("tidy_data-", Sys.Date(), ".csv", sep="")
-    },
+  output$download_full_csv <- downloadHandler(
+    filename = function() paste0("tidied_data_", Sys.Date(), ".csv"),
     content = function(file) {
-      req(tidy_data())  # Ensure there is tidied data to download
-      write.csv(tidy_data(), file, row.names = FALSE)
+      write_excel_csv(tidied_data(), file, row.names = FALSE)
     }
   )
 
-  output$tidydata_head <- renderPrint({
+  output$tidydata_table <- DT::renderDT({
     req(tidy_data())
-    head(tidy_data())
+    DT::datatable(tidy_data(), extensions = c('Buttons'),
+      options = list(dom = 'Bfrtip', buttons = list('csv', 'excel')),
+      rownames = FALSE)
   })
 
   output$gg_TRHplot <- renderPlot({
@@ -43,5 +44,4 @@ server <- function(input, output, session) {
       theme_bw()
   })
 
-
 }
